==> ejc-ztpcct-impl-3.0.0-20240509.084707-151-sources.jar: com/ejianc/ztpc/controller/OpinionInfoController.java <==
package com.ejianc.ztpc.controller;

import java.io.*;

import cn.afterturn.easypoi.word.WordExportUtil;
import cn.afterturn.easypoi.word.entity.MyXWPFDocument;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.ztpc.bean.ConstructionSchemeEntity;
import com.ejianc.ztpc.service.IConstructionSchemeService;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.ztpc.bean.OpinionInfoEntity;
import com.ejianc.ztpc.service.IOpinionInfoService;
import com.ejianc.ztpc.vo.OpinionInfoVO;

/**
 * 意见栏
 *
 * @author generator
 */
@Controller
@RequestMapping("opinionInfo")
public class OpinionInfoController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IOpinionInfoService service;
    @Autowired
    private IConstructionSchemeService constructionSchemeService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OpinionInfoVO> saveOrUpdate(@RequestBody OpinionInfoVO saveOrUpdateVO) {
        OpinionInfoEntity entity = BeanMapper.map(saveOrUpdateVO, OpinionInfoEntity.class);
        if (entity.getId() == null || entity.getId() == 0) {
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        service.saveOrUpdate(entity, false);
        OpinionInfoVO vo = BeanMapper.map(entity, OpinionInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OpinionInfoVO> queryDetail(Long id) {
        OpinionInfoEntity entity = service.selectById(id);
        OpinionInfoVO vo = BeanMapper.map(entity, OpinionInfoVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OpinionInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (OpinionInfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(OpinionInfoVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OpinionInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<OpinionInfoEntity> page = service.queryPage(param, false);
        IPage<OpinionInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), OpinionInfoVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
//        /** 模糊搜索配置字段示例 */
//        List<String> fuzzyFields = param.getFuzzyFields();
//        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
//        param.setPageIndex(1);
//        param.setPageSize(-1);
//        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
//        List<OpinionInfoEntity> list = service.queryList(param);
//        //todo:字段翻译等等
//        Map<String, Object> beans = new HashMap<>();
//        beans.put("records", list);
//        ExcelExport.getInstance().export("OpinionInfo-export.xlsx", beans, response);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<OpinionInfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        ConstructionSchemeEntity entity = null;
        Map<String, Object> wordMap = null;
        if (list == null||list.size() == 0) {
            return;
        }
        entity = constructionSchemeService.selectById(list.get(0).getPid());
        String id ="";
        if(param.getParams().get("id")!=null){
            id=param.getParams().get("id").getValue().toString();
        }
        if (id == null||id=="") {
            return;
        }
        String[] idStrings = id.substring(1, id.length() - 1).split(",");
        List<Long> ids = new ArrayList<>();
        for (String str : idStrings) {
            try {
                ids.add(Long.parseLong(str.trim()));
            } catch (NumberFormatException e) {
                e.printStackTrace();
            }
        }
        wordMap=service.toWordMap(entity,ids);
        try {
            try (
                    InputStream resourceAsStream = getClass().getResourceAsStream("/excel/constructionScheme-opinion-export.docx");
            ) {
                XWPFDocument document = new MyXWPFDocument(resourceAsStream);
                WordExportUtil.exportWord07(document, wordMap);
                ByteArrayOutputStream out = new ByteArrayOutputStream();
                try {
                    document.write(out);
                    out.close();

                } catch (IOException e) {
                    e.printStackTrace();
                }

                // 获取二进制数据
                byte[] fileData = out.toByteArray();

                // 设置HTTP响应头，告诉前端返回的是一个Word文档
                response.setContentType("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
                String fileName = "审核意见汇总(" + entity.getConsSchemeName() + ").docx";
                response.setHeader("Content-Disposition", "attachment; filename=" + fileName);

                // 将字节数组写入到response的输出流中
                try (ByteArrayInputStream bais = new ByteArrayInputStream(fileData)) {
                    byte[] buffer = new byte[1024];
                    int bytesRead;
                    while ((bytesRead = bais.read(buffer)) != -1) {
                        response.getOutputStream().write(buffer, 0, bytesRead);
                    }
                    response.flushBuffer();
                } catch (IOException e) {
                    e.printStackTrace();
                    // 处理异常，确保资源被正确关闭等
                    // 这里你可能需要返回一个错误响应给前端
                }

            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refOpinionInfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<OpinionInfoVO>> refOpinionInfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                   String condition,
                                                                   String searchObject,
                                                                   String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<OpinionInfoEntity> page = service.queryPage(param, false);
        IPage<OpinionInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), OpinionInfoVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}

==> ejc-ztpcct-impl-3.0.0-20240819.032736-178-sources.jar: com/ejianc/ztpc/controller/OpinionInfoController.java <==
package com.ejianc.ztpc.controller;

import java.io.*;

import cn.afterturn.easypoi.word.WordExportUtil;
import cn.afterturn.easypoi.word.entity.MyXWPFDocument;
import com.alibaba.fastjson.JSON;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.ztpc.bean.ConstructionSchemeEntity;
import com.ejianc.ztpc.service.IConstructionSchemeService;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.ztpc.bean.OpinionInfoEntity;
import com.ejianc.ztpc.service.IOpinionInfoService;
import com.ejianc.ztpc.vo.OpinionInfoVO;

/**
 * 意见栏
 *
 * @author generator
 */
@Controller
@RequestMapping("opinionInfo")
public class OpinionInfoController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IOpinionInfoService service;
    @Autowired
    private IConstructionSchemeService constructionSchemeService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OpinionInfoVO> saveOrUpdate(@RequestBody OpinionInfoVO saveOrUpdateVO) {
        OpinionInfoEntity entity = BeanMapper.map(saveOrUpdateVO, OpinionInfoEntity.class);
//        if (entity.getId() == null || entity.getId() == 0) {
//            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
//            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
//            if (billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
//            } else {
//                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
//            }
//        }
        service.saveOrUpdate(entity, false);
        OpinionInfoVO vo = BeanMapper.map(entity, OpinionInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    @RequestMapping(value = "/saveOrUpdateList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<OpinionInfoVO>> saveOrUpdate(@RequestBody List<OpinionInfoVO> saveOrUpdateVOList) {
        if (saveOrUpdateVOList == null || saveOrUpdateVOList.size() == 0){
            return CommonResponse.error("参数为空");
        }
        logger.info("传入数据:"+JSON.toJSONString(saveOrUpdateVOList));
        Long userid = InvocationInfoProxy.getUserid();
        logger.info("用户信息:"+userid);
        for (OpinionInfoVO opinionInfo : saveOrUpdateVOList) {
            Long proposeUserId = opinionInfo.getProposeUserId();
            OpinionInfoEntity entity = BeanMapper.map(opinionInfo, OpinionInfoEntity.class);
            if (userid != null && userid.equals(proposeUserId)){
                logger.info("已经修改保存的意见:"+JSON.toJSONString(opinionInfo));
                opinionInfo.setTenantId(InvocationInfoProxy.getTenantid());
                service.saveOrUpdate(entity);
            }
        }
        ConstructionSchemeEntity constructionSchemeEntity = constructionSchemeService.selectById(saveOrUpdateVOList.get(0).getPid());
        List<OpinionInfoVO> opinionInfoVOS = BeanMapper.mapList(constructionSchemeEntity.getOpinionInfoList(), OpinionInfoVO.class);
        return CommonResponse.success("保存或修改单据成功！", opinionInfoVOS);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OpinionInfoVO> queryDetail(Long id) {
        OpinionInfoEntity entity = service.selectById(id);
        OpinionInfoVO vo = BeanMapper.map(entity, OpinionInfoVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OpinionInfoVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (OpinionInfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(OpinionInfoVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OpinionInfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if (5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<OpinionInfoEntity> page = service.queryPage(param, false);
        IPage<OpinionInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), OpinionInfoVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
//        /** 模糊搜索配置字段示例 */
//        List<String> fuzzyFields = param.getFuzzyFields();
//        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
//        param.setPageIndex(1);
//        param.setPageSize(-1);
//        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
//        List<OpinionInfoEntity> list = service.queryList(param);
//        //todo:字段翻译等等
//        Map<String, Object> beans = new HashMap<>();
//        beans.put("records", list);
//        ExcelExport.getInstance().export("OpinionInfo-export.xlsx", beans, response);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
//        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
//        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<OpinionInfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        ConstructionSchemeEntity entity = null;
        Map<String, Object> wordMap = null;
        if (list == null||list.size() == 0) {
            return;
        }
        entity = constructionSchemeService.selectById(list.get(0).getPid());
        String id ="";
        if(param.getParams().get("id")!=null){
            id=param.getParams().get("id").getValue().toString();
        }
        if (id == null||id=="") {
            return;
        }
        String[] idStrings = id.substring(1, id.length() - 1).split(",");
        List<Long> ids = new ArrayList<>();
        for (String str : idStrings) {
            try {
                ids.add(Long.parseLong(str.trim()));
            } catch (NumberFormatException e) {
                e.printStackTrace();
            }
        }
        wordMap=service.toWordMap(entity,ids);
        try {
            try (
                    InputStream resourceAsStream = getClass().getResourceAsStream("/excel/constructionScheme-opinion-export.docx");
            ) {
                XWPFDocument document = new MyXWPFDocument(resourceAsStream);
                WordExportUtil.exportWord07(document, wordMap);
                ByteArrayOutputStream out = new ByteArrayOutputStream();
                try {
                    document.write(out);
                    out.close();

                } catch (IOException e) {
                    e.printStackTrace();
                }

                // 获取二进制数据
                byte[] fileData = out.toByteArray();

                // 设置HTTP响应头，告诉前端返回的是一个Word文档
                response.setContentType("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
                String fileName = "审核意见汇总(" + entity.getConsSchemeName() + ").docx";
                response.setHeader("Content-Disposition", "attachment; filename=" + fileName);

                // 将字节数组写入到response的输出流中
                try (ByteArrayInputStream bais = new ByteArrayInputStream(fileData)) {
                    byte[] buffer = new byte[1024];
                    int bytesRead;
                    while ((bytesRead = bais.read(buffer)) != -1) {
                        response.getOutputStream().write(buffer, 0, bytesRead);
                    }
                    response.flushBuffer();
                } catch (IOException e) {
                    e.printStackTrace();
                    // 处理异常，确保资源被正确关闭等
                    // 这里你可能需要返回一个错误响应给前端
                }

            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refOpinionInfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<OpinionInfoVO>> refOpinionInfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                   String condition,
                                                                   String searchObject,
                                                                   String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<OpinionInfoEntity> page = service.queryPage(param, false);
        IPage<OpinionInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), OpinionInfoVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }
}
